@@ -1,12 +1,12 @@
 package Imager::Font::T1;
+use 5.006;
 use strict;
 use Imager::Color;
-use vars qw(@ISA $VERSION);
-@ISA = qw(Imager::Font);
+our @ISA = qw(Imager::Font);
 use Scalar::Util ();
 
 BEGIN {
-  $VERSION = "1.023";
+  our $VERSION = "1.030";
 
   require XSLoader;
   XSLoader::load('Imager::Font::T1', $VERSION);
@@ -23,12 +23,14 @@ sub new {
 	   size=>15,
 	   @_);
 
-  unless ($hsh{file}) {
+  my $file = $hsh{file};
+  my $afm  = $hsh{afm};
+  unless (defined $file) {
     $Imager::ERRSTR = "No font file specified";
     return;
   }
-  unless (-e $hsh{file}) {
-    $Imager::ERRSTR = "Font file $hsh{file} not found";
+  unless (-e $file) {
+    $Imager::ERRSTR = "Font file $file not found";
     return;
   }
   unless ($Imager::formats{t1}) {
@@ -36,27 +38,28 @@ sub new {
     return;
   }
   # we want to avoid T1Lib's file search mechanism
-  unless ($hsh{file} =~ m!^/!
-	  || $hsh{file} =~ m!^\.\/?/!
-	  || $^O =~ /^(MSWin32|cygwin)$/ && $hsh{file} =~ /^[a-z]:/i) {
-    $hsh{file} = './' . $hsh{file};
+  unless ($file =~ m!^/!
+	  || $file =~ m!^\.\/?/!
+	  || $^O =~ /^(MSWin32|cygwin)$/ && $file =~ /^[a-z]:/i) {
+    $file = './' . $file;
   }
 
-  if($hsh{afm}) {
-	  unless (-e $hsh{afm}) {
-	    $Imager::ERRSTR = "Afm file $hsh{afm} not found";
-	    return;
-	  }
-	  unless ($hsh{afm} =~ m!^/!
-		  || $hsh{afm} =~ m!^\./!
-		  || $^O =~ /^(MSWin32|cygwin)$/ && $hsh{file} =~ /^[a-z]:/i) {
-	    $hsh{file} = './' . $hsh{file};
-	  }
-  } else {
-	  $hsh{afm} = 0;
+  if(defined $afm && length $afm) {
+    unless (-e $afm) {
+      $Imager::ERRSTR = "Afm file $afm not found";
+      return;
+    }
+    unless ($afm =~ m!^/!
+            || $afm =~ m!^\./!
+            || $^O =~ /^(MSWin32|cygwin)$/ && $file =~ /^[a-z]:/i) {
+      $afm = './' . $afm;
+    }
+  }
+  else {
+    $afm = undef;
   }
 
-  my $font = Imager::Font::T1xs->new($hsh{file},$hsh{afm});
+  my $font = Imager::Font::T1xs->new($file, $afm);
   unless ($font) { # the low-level code may miss some error handling
     Imager->_set_error(Imager->_error_as_msg);
     return;
@@ -64,7 +67,7 @@ sub new {
   return bless {
 		t1font    => $font,
 		aa    => $hsh{aa} || 0,
-		file  => $hsh{file},
+		file  => $file,
 		type  => 't1',
 		size  => $hsh{size},
 		color => $hsh{color},
@@ -233,7 +236,15 @@ __END__
 
 =head1 DESCRIPTION
 
-Imager::Font creates a Imager::Font::Type1 object when asked to create
+=for stopwords Freetype
+
+Imager::Font::T1 is deprecated.
+
+F<T1Lib> is unmaintained and has serious bugs when built on 64-bit
+systems.  Freetype 2 has Type 1 font support and is supported by
+Imager via L<Imager::Font::FT2>.
+
+L<Imager::Font> creates a C<Imager::Font::Type1 object> when asked to create
 a font object based on a C<.pfb> file.
 
 See Imager::Font to see how to use this type.
